@@ -46,6 +46,7 @@ except ImportError:
 ## Fixtures
 ##########################################################################
 
+
 class FakeClassifier(BaseEstimator, ClassifierMixin):
     """
     A fake classifier for testing noops on the visualizer.
@@ -129,7 +130,9 @@ class TestROCAUC(VisualTestCase):
         Test ROCAUC binary classifier with both decision & predict_proba with per_class=False
         """
         # Create and fit the visualizer
-        visualizer = ROCAUC(AdaBoostClassifier(), micro=False, macro=False, per_class=False)
+        visualizer = ROCAUC(
+            AdaBoostClassifier(), micro=False, macro=False, per_class=False
+        )
         visualizer.fit(self.binary.X.train, self.binary.y.train)
 
         # Score the visualizer
@@ -271,9 +274,7 @@ class TestROCAUC(VisualTestCase):
         Test ROCAUC with no curves specified at all
         """
         # Create and fit the visualizer
-        visualizer = ROCAUC(
-            GaussianNB(), per_class=False, macro=False, micro=False
-        )
+        visualizer = ROCAUC(GaussianNB(), per_class=False, macro=False, micro=False)
         visualizer.fit(self.multiclass.X.train, self.multiclass.y.train)
 
         # Attempt to score the visualizer
@@ -432,6 +433,19 @@ class TestROCAUC(VisualTestCase):
         # Check to see if the first 10 y_scores match the expected
         npt.assert_array_almost_equal(y_scores[:10], first_ten_expected, decimal=1)
 
+    def test_binary_false_decision_function_error(self):
+        """
+        Test binary decision_function model raises error when the binary param is False
+        """
+        # Create and fit the visualizer
+        visualizer = ROCAUC(LinearSVC(random_state=42), binary=False)
+        visualizer.fit(self.binary.X.train, self.binary.y.train)
+
+        # Ensure score raises error
+        # (only binary curve defined for binary decisions with decision_function clf)
+        with pytest.raises(ModelError):
+            visualizer.score(self.binary.X.test, self.binary.y.test)
+
     def test_multi_decision_function_rocauc(self):
         """
         Test ROCAUC with multiclass classifiers that have a decision function
