@@ -116,6 +116,15 @@ class TestKElbowHelper(object):
         score = distortion_score(df, s)
         assert score == pytest.approx(69.10006514142941)
 
+    def test_distortion_score_empty_clusters(self):
+        """
+        Ensure no ValueError is thrown when there are empty clusters #1185
+        """
+        X = np.array([[1,2],[3,4],[5,6]])
+        valuea = distortion_score(X, np.array([1,3,3]))
+        valueb = distortion_score(X, np.array([0,1,1]))
+        assert valuea == valueb
+
 
 ##########################################################################
 ## KElbowVisualizer Test Cases
@@ -129,6 +138,7 @@ class TestKElbowVisualizer(VisualTestCase):
     """
 
     @pytest.mark.xfail(reason="images not close due to timing lines")
+    @pytest.mark.filterwarnings("ignore:No 'knee'")
     def test_integrated_kmeans_elbow(self):
         """
         Test no exceptions for kmeans k-elbow visualizer on blobs dataset
@@ -152,6 +162,7 @@ class TestKElbowVisualizer(VisualTestCase):
             pytest.fail("error during k-elbow: {}".format(e))
 
     @pytest.mark.xfail(reason="images not close due to timing lines")
+    @pytest.mark.filterwarnings("ignore:No 'knee'")
     def test_integrated_mini_batch_kmeans_elbow(self):
         """
         Test no exceptions for mini-batch kmeans k-elbow visualizer
@@ -423,6 +434,31 @@ class TestKElbowVisualizer(VisualTestCase):
         custom_title = "My custom title"
         model = KMeans(3, random_state=13)
         oz = kelbow_visualizer(
-            model, X, sample_weight=np.ones(X.shape[0]), title=custom_title
+            model, X, sample_weight=np.ones(X.shape[0]), title=custom_title, show=False
         )
         assert oz.title == custom_title
+
+    @pytest.mark.xfail(sys.platform == "win32", reason="images not close on windows")
+    def test_set_colors_manually(self):
+        """
+        Test the silhouette metric of the k-elbow visualizer
+        """
+        oz = KElbowVisualizer(
+            KMeans(random_state=0), k=5,
+        )
+
+        oz.metric_color = "r"
+        oz.timing_color = "y"
+        oz.vline_color = "c"
+
+        # Create artificial "fit" data for testing purposes
+        oz.k_values_ = [1, 2, 3, 4, 5, 6, 7, 8]
+        oz.k_timers_ = [6.2, 8.3, 10.1, 15.8, 21.2, 27.9, 38.2, 44.9]
+        oz.k_scores_ = [.8, .7, .55, .48, .40, .38, .35, .30]
+        oz.elbow_value_ = 5
+        oz.elbow_score_ = 0.40
+
+        # Execute drawing
+        oz.draw()
+        oz.finalize()
+        self.assert_images_similar(oz, tol=3.2)
\ No newline at end of file
