@@ -228,7 +228,7 @@ class TestFeatureImportancesVisualizer(VisualTestCase):
         """
         Test stack plot with multidimensional coefficients
         """
-        X, y = load_iris(True)
+        X, y = load_iris(return_X_y=True)
 
         viz = FeatureImportances(
             LogisticRegression(solver="liblinear", random_state=222), stack=True
@@ -240,6 +240,22 @@ class TestFeatureImportancesVisualizer(VisualTestCase):
         # Appveyor and Linux conda non-text-based differences
         self.assert_images_similar(viz, tol=17.5)
 
+    def test_stack_param_incorrectly_used_throws_error(self):
+        """
+        Test incorrectly using stack param on a dataset with two classes which
+        does not return a coef_ array in the shape of (n_classes, n_features)
+        """
+        X, y = load_occupancy()
+
+        viz = FeatureImportances(
+            LogisticRegression(solver="liblinear", random_state=222), stack=True
+        )
+
+        expected_error = "The model used does not return coef_ array"
+
+        with pytest.raises(YellowbrickValueError, match=expected_error):
+            viz.fit(X, y)
+
     @pytest.mark.skipif(pd is None, reason="pandas is required for this test")
     def test_fit_dataframe(self):
         """
@@ -439,7 +455,7 @@ class TestFeatureImportancesVisualizer(VisualTestCase):
         Test stack plot with only the three most important features by sum of
         each feature's importance across all classes
         """
-        X, y = load_iris(True)
+        X, y = load_iris(return_X_y=True)
 
         viz = FeatureImportances(
             LogisticRegression(solver="liblinear", random_state=222),
@@ -457,7 +473,7 @@ class TestFeatureImportancesVisualizer(VisualTestCase):
         Test stack plot with only the three least important features by sum of
         each feature's importance across all classes
         """
-        X, y = load_iris(True)
+        X, y = load_iris(return_X_y=True)
 
         viz = FeatureImportances(
             LogisticRegression(solver="liblinear", random_state=222),
@@ -474,7 +490,7 @@ class TestFeatureImportancesVisualizer(VisualTestCase):
         """
         Test plot with only top three important features by absolute value
         """
-        X, y = load_iris(True)
+        X, y = load_iris(return_X_y=True)
 
         viz = FeatureImportances(
             GradientBoostingClassifier(random_state=42), topn=3
@@ -489,7 +505,7 @@ class TestFeatureImportancesVisualizer(VisualTestCase):
         """
         Test plot with only the three least important features by absolute value
         """
-        X, y = load_iris(True)
+        X, y = load_iris(return_X_y=True)
 
         viz = FeatureImportances(
             GradientBoostingClassifier(random_state=42), topn=-3
