@@ -91,6 +91,12 @@ class ClassificationReport(ClassificationScoreVisualizer):
         will prevent an exception when the visualizer is initialized but may result
         in unexpected or unintended behavior.
 
+    colorbar : bool, default: True
+        Specify if the color bar should be present
+
+    fontsize : int or None, default: None
+        Specify the font size of the x and y labels
+
     kwargs : dict
         Keyword arguments passed to the visualizer base classes.
 
@@ -132,6 +138,8 @@ class ClassificationReport(ClassificationScoreVisualizer):
         encoder=None,
         is_fitted="auto",
         force_model=False,
+        colorbar=True,
+        fontsize=None,
         **kwargs
     ):
         super(ClassificationReport, self).__init__(
@@ -144,11 +152,13 @@ class ClassificationReport(ClassificationScoreVisualizer):
             **kwargs
         )
 
+        self.colorbar = colorbar
         self.support = support
         self.cmap = color_sequence(cmap)
         self.cmap.set_over(color=CMAP_OVERCOLOR)
         self.cmap.set_under(color=CMAP_UNDERCOLOR)
         self._displayed_scores = [key for key in SCORES_KEYS]
+        self.fontsize=fontsize
 
         if support not in {None, True, False, "percent", "count"}:
             raise YellowbrickValueError(
@@ -223,6 +233,26 @@ class ClassificationReport(ClassificationScoreVisualizer):
         self.ax.set_ylim(bottom=0, top=cr_display.shape[0])
         self.ax.set_xlim(left=0, right=cr_display.shape[1])
 
+        # Get the human readable labels
+        labels = self._labels()
+        if labels is None:
+            labels = self.classes_
+
+        # Fetch the grid labels from the classes in correct order; set ticks.
+        xticklabels = self._displayed_scores
+        yticklabels = labels[::-1]
+        
+        yticks = np.arange(len(labels)) + 0.5
+        xticks = np.arange(len(self._displayed_scores)) + 0.5
+
+        self.ax.set(yticks=yticks, xticks=xticks)
+
+        self.ax.set_xticklabels(
+            xticklabels, rotation=45, fontsize=self.fontsize
+            )
+        self.ax.set_yticklabels(yticklabels, fontsize=self.fontsize)
+
+
         # Set data labels in the grid, enumerating over class, metric pairs
         # NOTE: X and Y are one element longer than the classification report
         # so skip the last element to label the grid correctly.
@@ -255,7 +285,10 @@ class ClassificationReport(ClassificationScoreVisualizer):
         )
 
         # Add the color bar
-        plt.colorbar(g, ax=self.ax)  # TODO: Could use self.fig now
+        if self.colorbar:
+            plt.colorbar(g, ax=self.ax)  # TODO: Could use self.fig now
+        else:
+            pass
 
         # Return the axes being drawn on
         return self.ax
@@ -300,6 +333,8 @@ def classification_report(
     is_fitted="auto",
     force_model=False,
     show=True,
+    colorbar=True,
+    fontsize=None,
     **kwargs
 ):
     """Classification Report
@@ -373,6 +408,12 @@ def classification_report(
         If True, calls ``show()``, which in turn calls ``plt.show()`` however you cannot
         call ``plt.savefig`` from this signature, nor ``clear_figure``. If False, simply
         calls ``finalize()``
+    
+    colorbar : bool, default: True
+        Specify if the color bar should be present
+
+    fontsize : int or None, default: None
+        Specify the font size of the x and y labels
 
     kwargs : dict
         Keyword arguments passed to the visualizer base classes.
@@ -392,6 +433,8 @@ def classification_report(
         encoder=encoder,
         is_fitted=is_fitted,
         force_model=force_model,
+        colorbar=colorbar,
+        fontsize=fontsize,
         **kwargs
     )
 
